@@ -29,12 +29,12 @@ if ($^O eq 'MSWin32') {
 }
 $parser->getopts("hi:vx");
 if ($parser->YYData->{opt_v}) {
-	print "CORBA::Cplusplus $CORBA::Cplusplus::VERSION\n";
-	print "CORBA::C $CORBA::C::VERSION\n";
-	print "CORBA::IDL $CORBA::IDL::VERSION\n";
+	print "CORBA::Cplusplus $CORBA::Cplusplus::include::VERSION\n";
+	print "CORBA::C $CORBA::C::include::VERSION\n";
+	print "CORBA::IDL $CORBA::IDL::node::VERSION\n";
 	print "IDL $Parser::IDL_version\n";
 	print "$0\n";
-	print "Perl $]\n";
+	print "Perl $] on $^O\n";
 	exit;
 }
 if ($parser->YYData->{opt_h}) {
